pub enum DecisionAttemptErrorCode {
Show 17 variants
SimulationRevisionConflict,
CommandRequestConflict,
EntityUnavailable,
ClosedTicket,
DuplicateController,
DuplicateResponse,
DuplicateTicket,
DecisionHistoryUnavailable,
InvalidController,
InvalidDecision,
InvalidOption,
PolicyMismatch,
TicketNotFound,
QueryBudgetExceeded,
VersionConflict,
IssuerUnavailable,
DecisionMakerUnavailable,
}Variants
SimulationRevisionConflict
CommandRequestConflict
ClosedTicket
DuplicateController
DuplicateResponse
DuplicateTicket
InvalidController
InvalidDecision
InvalidOption
PolicyMismatch
TicketNotFound
QueryBudgetExceeded
VersionConflict
The resolving controller acts for a person who is not alive or is detained or captive.
The decision maker is a person who is not alive or is detained or captive.