pub struct BoundaryRecord {Show 27 fields
pub id: BoundaryId,
pub at: SimTime,
pub correlation_id: u64,
pub cadences: Vec<SystemCadence>,
pub admitted_attempts: Vec<CommandAttemptId>,
pub admitted_commands: Vec<CommandId>,
pub admitted_ingress: Vec<IngressId>,
pub generated_ingress: Vec<BoundaryIngressGeneration>,
pub admitted_events: Vec<EventId>,
pub reservation_offers: Vec<ReservationOfferRecord>,
pub reservation_requests: Vec<ReservationRequestRecord>,
pub allocations: Vec<ReservationAllocation>,
pub random_draws: Vec<RandomDrawId>,
pub changes: Vec<BoundaryChange>,
pub record_changes: Vec<DomainRecordChange>,
pub knowledge_changes: Vec<BoundaryKnowledgeChange>,
pub maintenance_changes: Vec<MaintenanceChangeRecord>,
pub maintenance_terminal_root: Option<String>,
pub person_availability_changes: Vec<BoundaryPersonAvailabilityChange>,
pub created_persons: Vec<BoundaryPersonCreation>,
pub evaluation_traces: Vec<BoundaryEvaluationTrace>,
pub transition_manifests: Vec<PendingTransitionManifest>,
pub transition_audits: Vec<TransitionAuditRecord>,
pub emissions: Vec<BoundaryEmission>,
pub state_hash: Option<String>,
pub previous_hash: String,
pub hash: String,
}Fields
id: BoundaryIdat: SimTimecorrelation_id: u64cadences: Vec<SystemCadence>admitted_attempts: Vec<CommandAttemptId>admitted_commands: Vec<CommandId>admitted_ingress: Vec<IngressId>generated_ingress: Vec<BoundaryIngressGeneration>admitted_events: Vec<EventId>reservation_offers: Vec<ReservationOfferRecord>reservation_requests: Vec<ReservationRequestRecord>allocations: Vec<ReservationAllocation>random_draws: Vec<RandomDrawId>changes: Vec<BoundaryChange>record_changes: Vec<DomainRecordChange>knowledge_changes: Vec<BoundaryKnowledgeChange>maintenance_changes: Vec<MaintenanceChangeRecord>maintenance_terminal_root: Option<String>person_availability_changes: Vec<BoundaryPersonAvailabilityChange>created_persons: Vec<BoundaryPersonCreation>evaluation_traces: Vec<BoundaryEvaluationTrace>Rule-evaluation traces recorded by this boundary’s systems, in system execution order.
transition_manifests: Vec<PendingTransitionManifest>Transition manifests registered in this boundary, in admission order.
transition_audits: Vec<TransitionAuditRecord>Manifests settled at this, their ready boundary, in manifest-ID order.
emissions: Vec<BoundaryEmission>state_hash: Option<String>Untagged legacy full-state hash or a v1: incremental state commitment.
previous_hash: Stringhash: StringTrait Implementations
Sourceimpl Clone for BoundaryRecord
impl Clone for BoundaryRecord
Sourcefn clone(&self) -> BoundaryRecord
fn clone(&self) -> BoundaryRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundaryRecord
impl Debug for BoundaryRecord
Sourceimpl<'de> Deserialize<'de> for BoundaryRecord
impl<'de> Deserialize<'de> for BoundaryRecord
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BoundaryRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BoundaryRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BoundaryRecord
impl PartialEq for BoundaryRecord
Sourceimpl Serialize for BoundaryRecord
impl Serialize for BoundaryRecord
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for BoundaryRecord