pub struct CapacityBooking {
pub id: CapacityBookingId,
pub execution: TransportExecutionId,
pub resource: String,
pub valid_from: SimTime,
pub valid_until: SimTime,
pub quantity: u64,
pub priority: i32,
pub status: CapacityBookingStatus,
pub allocation_evidence: Vec<EvidenceRef>,
}Fields
id: CapacityBookingIdexecution: TransportExecutionIdresource: Stringvalid_from: SimTimevalid_until: SimTimequantity: u64priority: i32status: CapacityBookingStatusallocation_evidence: Vec<EvidenceRef>Implementations
Sourceimpl CapacityBooking
impl CapacityBooking
pub fn new( id: CapacityBookingId, execution: TransportExecutionId, resource: String, valid_from: SimTime, valid_until: SimTime, quantity: u64, priority: i32, ) -> Result<CapacityBooking, TransportError>
Sourcepub fn transition(
&mut self,
status: CapacityBookingStatus,
at: SimTime,
) -> Result<(), TransportError>
pub fn transition( &mut self, status: CapacityBookingStatus, at: SimTime, ) -> Result<(), TransportError>
Moves the booking through its windowed state machine.
A request may be confirmed, failed, or cancelled, and a confirmed booking released or cancelled, before its window opens; capacity can only be consumed inside the window, confirmed only until it ends, and expired only after it ends.