DecisionTicket

Struct DecisionTicket 

pub struct DecisionTicket {
Show 13 fields pub id: DecisionTicketId, pub definition: String, pub decision_maker: EntityRef, pub assigned_controller: String, pub summary: String, pub context: DecisionContext, pub options: Vec<DecisionOption>, pub opened_at: SimTime, pub updated_at: SimTime, pub deadline: Option<SimTime>, pub version: u64, pub state: DecisionTicketState, pub parent_ticket: Option<DecisionTicketId>,
}

Fields

id: DecisionTicketIddefinition: Stringdecision_maker: EntityRefassigned_controller: Stringsummary: Stringcontext: DecisionContextoptions: Vec<DecisionOption>opened_at: SimTimeupdated_at: SimTimedeadline: Option<SimTime>version: u64state: DecisionTicketStateparent_ticket: Option<DecisionTicketId>

Terminal ticket that this ticket follows, of the same decision maker or of a controller bound to the same seat (see DecisionTicketDraft::parent_ticket).

Implementations

Source

impl DecisionTicket

pub fn option(&self, id: &str) -> Option<&DecisionOption>

pub const fn is_open(&self) -> bool