pub struct MovementOrderId(pub u64);Expand description
Stable identity for an admitted transport-domain movement intent.
The simulation admits movement through a host- or integration-defined command. This record adds route-plan and custody evidence when a transport domain needs to persist a richer execution than its own projected transit state.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for MovementOrderId
impl Clone for MovementOrderId
Sourcefn clone(&self) -> MovementOrderId
fn clone(&self) -> MovementOrderId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MovementOrderId
Sourceimpl Debug for MovementOrderId
impl Debug for MovementOrderId
Sourceimpl<'de> Deserialize<'de> for MovementOrderId
impl<'de> Deserialize<'de> for MovementOrderId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MovementOrderId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MovementOrderId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MovementOrderId
Sourceimpl Hash for MovementOrderId
impl Hash for MovementOrderId
Sourceimpl Ord for MovementOrderId
impl Ord for MovementOrderId
Sourcefn cmp(&self, other: &MovementOrderId) -> Ordering
fn cmp(&self, other: &MovementOrderId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MovementOrderId
impl PartialEq for MovementOrderId
Sourceimpl PartialOrd for MovementOrderId
impl PartialOrd for MovementOrderId
Sourceimpl Serialize for MovementOrderId
impl Serialize for MovementOrderId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for MovementOrderId