PluginRegistrar

Struct PluginRegistrar 

pub struct PluginRegistrar<'a> { /* private fields */ }

Implementations

Source

impl PluginRegistrar<'_>

pub fn register_archive_reachability_participant( &mut self, handler: fn(&SimulationView<'_>, &dyn PluginArchiveObjectProvider, &mut ArchiveReachabilityManifest) -> Result<(), CanwuError>, ) -> Result<(), CanwuError>

pub fn register_owner_authorized_maintenance_participant( &mut self, handler: fn(&SimulationView<'_>, &OwnerAuthorizedMaintenanceRequest, OwnerAuthorizedParticipantRole) -> Result<OwnerAuthorizedParticipantDraft, CanwuError>, ) -> Result<(), CanwuError>

pub fn register_maintenance_dependency_resolver( &mut self, target_namespace: impl Into<String>, ) -> Result<(), CanwuError>

pub fn register_record_schema( &mut self, schema: DomainRecordSchema, ) -> Result<(), CanwuError>

Examples found in repository?
examples/governance_transition.rs (line 441)
427    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
428        let mut schema = DomainRecordSchema::for_record::<ReliefOrderRecord>();
429        schema.payload_schema = object_schema(&[
430            ("order_id", PayloadValueType::String),
431            ("issued_by", PayloadValueType::String),
432            ("treasury_system", PayloadValueType::String),
433            ("treasury_version", PayloadValueType::Integer),
434            ("treasury_disposition", PayloadValueType::String),
435            ("treasury_hash", PayloadValueType::String),
436            ("county_system", PayloadValueType::String),
437            ("county_version", PayloadValueType::Integer),
438            ("county_disposition", PayloadValueType::String),
439            ("county_hash", PayloadValueType::String),
440        ]);
441        registrar.register_record_schema(schema)?;
442        registrar.register_ingress(issue_descriptor())?;
443
444        let mut publish = BoundarySystemContract::new(
445            "publish-order",
446            BoundaryPhase::DomainDeltaProposal,
447            SystemCadence::EventDriven,
448        );
449        publish.reads = vec![order_state(), StateKey::core_ingress()];
450        publish.writes = vec![order_state()];
451        publish.plugin_ingress_targets = vec![
452            canwu_api::PluginIngressTarget {
453                target_plugin: TREASURY_PLUGIN.to_owned(),
454                packet_type: EXECUTE_INGRESS.to_owned(),
455            },
456            canwu_api::PluginIngressTarget {
457                target_plugin: COUNTY_PLUGIN.to_owned(),
458                packet_type: EXECUTE_INGRESS.to_owned(),
459            },
460        ];
461        publish.visibility = StateVisibility::SameBoundary;
462        registrar.register_boundary_system(publish, publish_order)?;
463
464        let mut audit = BoundarySystemContract::new(
465            "audit-order",
466            BoundaryPhase::StrategicAggregation,
467            SystemCadence::EventDriven,
468        );
469        audit.reads = vec![
470            order_state(),
471            treasury_state(),
472            county_state(),
473            StateKey::core_ingress(),
474        ];
475        registrar.register_boundary_system(audit, audit_order)
476    }
477}
478
479struct TreasuryPlugin;
480
481impl SimulationPlugin for TreasuryPlugin {
482    fn name(&self) -> &'static str {
483        TREASURY_PLUGIN
484    }
485
486    fn version(&self) -> &'static str {
487        "1"
488    }
489
490    fn semantic_hash(&self) -> &'static str {
491        "0000000000000000000000000000000000000000000000000000000000000302"
492    }
493
494    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
495        let mut schema = DomainRecordSchema::for_entity::<TreasuryActionRecord>();
496        schema.payload_schema = object_schema(&[
497            ("status", PayloadValueType::String),
498            ("grain_units", PayloadValueType::Integer),
499        ]);
500        registrar.register_record_schema(schema)?;
501        registrar.register_ingress(execute_descriptor())?;
502        let mut prepare = BoundarySystemContract::new(
503            "prepare-treasury",
504            BoundaryPhase::HistoricalCandidateEvaluation,
505            SystemCadence::EventDriven,
506        );
507        prepare.reads = vec![order_state(), StateKey::core_ingress()];
508        prepare.writes = vec![treasury_state()];
509        prepare.visibility = StateVisibility::SameBoundary;
510        registrar.register_boundary_system(prepare, prepare_treasury)
511    }
512}
513
514struct CountyPlugin;
515
516impl SimulationPlugin for CountyPlugin {
517    fn name(&self) -> &'static str {
518        COUNTY_PLUGIN
519    }
520
521    fn version(&self) -> &'static str {
522        "1"
523    }
524
525    fn semantic_hash(&self) -> &'static str {
526        "0000000000000000000000000000000000000000000000000000000000000303"
527    }
528
529    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
530        let mut schema = DomainRecordSchema::for_entity::<CountyActionRecord>();
531        schema.payload_schema = object_schema(&[
532            ("status", PayloadValueType::String),
533            ("grain_units", PayloadValueType::Integer),
534        ]);
535        registrar.register_record_schema(schema)?;
536        registrar.register_ingress(execute_descriptor())?;
537        let mut prepare = BoundarySystemContract::new(
538            "prepare-county",
539            BoundaryPhase::HistoricalCandidateEvaluation,
540            SystemCadence::EventDriven,
541        );
542        prepare.reads = vec![order_state(), StateKey::core_ingress()];
543        prepare.writes = vec![county_state()];
544        prepare.visibility = StateVisibility::SameBoundary;
545        registrar.register_boundary_system(prepare, prepare_county)
546    }
pub fn register_knowledge_schema( &mut self, schema: PluginKnowledgeSchema, ) -> Result<(), CanwuError>

pub fn register_schema(&mut self, schema: TypeSchema) -> Result<(), CanwuError>

pub fn register_event_audience( &mut self, event_type: impl Into<String>, audience: EventAudience, ) -> Result<(), CanwuError>

Declares the player-facing audience for one emitted plugin event type.

This policy is persisted in the plugin descriptor and is independent from the plugin system subscription graph. Event types without a declaration remain private to player-facing projections.

pub fn register_system( &mut self, contract: SystemContract, handler: fn(&SimulationView<'_>, &SimEvent) -> Result<Vec<SystemDirective>, CanwuError>, ) -> Result<(), CanwuError>

pub fn register_boundary_system( &mut self, contract: BoundarySystemContract, handler: fn(&SimulationView<'_>, &BoundaryContext) -> Result<BoundaryProposal, CanwuError>, ) -> Result<(), CanwuError>

Examples found in repository?
examples/phased_boundary.rs (line 104)
97    fn register(&self, registrar: &mut canwu_api::PluginRegistrar<'_>) -> Result<(), CanwuError> {
98        let mut contract = BoundarySystemContract::new(
99            "offer",
100            BoundaryPhase::ReservationAndAllocation,
101            SystemCadence::Daily,
102        );
103        contract.reservation_offers = vec![StateKey::new("logistics", "grain")];
104        registrar.register_boundary_system(contract, offer_grain)
105    }
106}
107
108struct DemandPlugin;
109
110impl SimulationPlugin for DemandPlugin {
111    fn name(&self) -> &'static str {
112        "example-demand"
113    }
114
115    fn version(&self) -> &'static str {
116        "1.0.0"
117    }
118
119    fn semantic_hash(&self) -> &'static str {
120        "331b865359d4ac4a14c9bf90da665b82b4aa65ee63c195e331d8f1fa181e7029"
121    }
122
123    fn register(&self, registrar: &mut canwu_api::PluginRegistrar<'_>) -> Result<(), CanwuError> {
124        let mut request = BoundarySystemContract::new(
125            "request",
126            BoundaryPhase::ReservationAndAllocation,
127            SystemCadence::Daily,
128        );
129        request.reservation_requests = vec![StateKey::new("logistics", "grain")];
130        registrar.register_boundary_system(request, request_grain)?;
131
132        let mut apply = BoundarySystemContract::new(
133            "apply",
134            BoundaryPhase::DomainDeltaProposal,
135            SystemCadence::Daily,
136        );
137        apply.writes = vec![StateKey::new("garrison", "grain")];
138        apply.emits = vec!["grain_allocated".to_owned()];
139        apply.reservation_reads = vec![ReservationRef::new(
140            "example-demand",
141            "request",
142            "daily-grain",
143        )];
144        apply.visibility = StateVisibility::SameBoundary;
145        registrar.register_boundary_system(apply, apply_grain)
146    }
More examples
Hide additional examples
examples/uncertainty_resolution.rs (line 92)
84    fn register(&self, registrar: &mut canwu_api::PluginRegistrar<'_>) -> Result<(), CanwuError> {
85        let mut contract = BoundarySystemContract::new(
86            "resolve-random-decision",
87            BoundaryPhase::StrategicAggregation,
88            SystemCadence::Daily,
89        );
90        contract.reads = vec![StateKey::core_decisions()];
91        contract.random_streams = vec![decision_stream()];
92        registrar.register_boundary_system(contract, random_resolution_system)
93    }
examples/governance_transition.rs (line 462)
427    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
428        let mut schema = DomainRecordSchema::for_record::<ReliefOrderRecord>();
429        schema.payload_schema = object_schema(&[
430            ("order_id", PayloadValueType::String),
431            ("issued_by", PayloadValueType::String),
432            ("treasury_system", PayloadValueType::String),
433            ("treasury_version", PayloadValueType::Integer),
434            ("treasury_disposition", PayloadValueType::String),
435            ("treasury_hash", PayloadValueType::String),
436            ("county_system", PayloadValueType::String),
437            ("county_version", PayloadValueType::Integer),
438            ("county_disposition", PayloadValueType::String),
439            ("county_hash", PayloadValueType::String),
440        ]);
441        registrar.register_record_schema(schema)?;
442        registrar.register_ingress(issue_descriptor())?;
443
444        let mut publish = BoundarySystemContract::new(
445            "publish-order",
446            BoundaryPhase::DomainDeltaProposal,
447            SystemCadence::EventDriven,
448        );
449        publish.reads = vec![order_state(), StateKey::core_ingress()];
450        publish.writes = vec![order_state()];
451        publish.plugin_ingress_targets = vec![
452            canwu_api::PluginIngressTarget {
453                target_plugin: TREASURY_PLUGIN.to_owned(),
454                packet_type: EXECUTE_INGRESS.to_owned(),
455            },
456            canwu_api::PluginIngressTarget {
457                target_plugin: COUNTY_PLUGIN.to_owned(),
458                packet_type: EXECUTE_INGRESS.to_owned(),
459            },
460        ];
461        publish.visibility = StateVisibility::SameBoundary;
462        registrar.register_boundary_system(publish, publish_order)?;
463
464        let mut audit = BoundarySystemContract::new(
465            "audit-order",
466            BoundaryPhase::StrategicAggregation,
467            SystemCadence::EventDriven,
468        );
469        audit.reads = vec![
470            order_state(),
471            treasury_state(),
472            county_state(),
473            StateKey::core_ingress(),
474        ];
475        registrar.register_boundary_system(audit, audit_order)
476    }
477}
478
479struct TreasuryPlugin;
480
481impl SimulationPlugin for TreasuryPlugin {
482    fn name(&self) -> &'static str {
483        TREASURY_PLUGIN
484    }
485
486    fn version(&self) -> &'static str {
487        "1"
488    }
489
490    fn semantic_hash(&self) -> &'static str {
491        "0000000000000000000000000000000000000000000000000000000000000302"
492    }
493
494    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
495        let mut schema = DomainRecordSchema::for_entity::<TreasuryActionRecord>();
496        schema.payload_schema = object_schema(&[
497            ("status", PayloadValueType::String),
498            ("grain_units", PayloadValueType::Integer),
499        ]);
500        registrar.register_record_schema(schema)?;
501        registrar.register_ingress(execute_descriptor())?;
502        let mut prepare = BoundarySystemContract::new(
503            "prepare-treasury",
504            BoundaryPhase::HistoricalCandidateEvaluation,
505            SystemCadence::EventDriven,
506        );
507        prepare.reads = vec![order_state(), StateKey::core_ingress()];
508        prepare.writes = vec![treasury_state()];
509        prepare.visibility = StateVisibility::SameBoundary;
510        registrar.register_boundary_system(prepare, prepare_treasury)
511    }
512}
513
514struct CountyPlugin;
515
516impl SimulationPlugin for CountyPlugin {
517    fn name(&self) -> &'static str {
518        COUNTY_PLUGIN
519    }
520
521    fn version(&self) -> &'static str {
522        "1"
523    }
524
525    fn semantic_hash(&self) -> &'static str {
526        "0000000000000000000000000000000000000000000000000000000000000303"
527    }
528
529    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
530        let mut schema = DomainRecordSchema::for_entity::<CountyActionRecord>();
531        schema.payload_schema = object_schema(&[
532            ("status", PayloadValueType::String),
533            ("grain_units", PayloadValueType::Integer),
534        ]);
535        registrar.register_record_schema(schema)?;
536        registrar.register_ingress(execute_descriptor())?;
537        let mut prepare = BoundarySystemContract::new(
538            "prepare-county",
539            BoundaryPhase::HistoricalCandidateEvaluation,
540            SystemCadence::EventDriven,
541        );
542        prepare.reads = vec![order_state(), StateKey::core_ingress()];
543        prepare.writes = vec![county_state()];
544        prepare.visibility = StateVisibility::SameBoundary;
545        registrar.register_boundary_system(prepare, prepare_county)
546    }
pub fn register_command( &mut self, descriptor: PluginActionDescriptor, handler: fn(&SimulationView<'_>, &CommandContext, &Value) -> Result<Vec<SystemDirective>, CanwuError>, ) -> Result<(), CanwuError>

Examples found in repository?
examples/plugin.rs (lines 57-84)
56    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
57        registrar.register_command(
58            PluginActionDescriptor {
59                name: "set_stance".to_owned(),
60                description: "Set an army stance through an issuer-aware command".to_owned(),
61                payload_schema: PayloadSchema::Object {
62                    properties: BTreeMap::from([
63                        (
64                            "army".to_owned(),
65                            PayloadProperty {
66                                value_type: PayloadValueType::Integer,
67                                required: true,
68                            },
69                        ),
70                        (
71                            "stance".to_owned(),
72                            PayloadProperty {
73                                value_type: PayloadValueType::String,
74                                required: true,
75                            },
76                        ),
77                    ]),
78                    allow_additional: false,
79                },
80                reads: vec![StateKey::core_armies()],
81                writes: vec![StateKey::new("military", "stance")],
82            },
83            set_stance,
84        )
85    }
pub fn register_ingress( &mut self, descriptor: PluginIngressDescriptor, ) -> Result<(), CanwuError>

Examples found in repository?
examples/governance_transition.rs (line 442)
427    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
428        let mut schema = DomainRecordSchema::for_record::<ReliefOrderRecord>();
429        schema.payload_schema = object_schema(&[
430            ("order_id", PayloadValueType::String),
431            ("issued_by", PayloadValueType::String),
432            ("treasury_system", PayloadValueType::String),
433            ("treasury_version", PayloadValueType::Integer),
434            ("treasury_disposition", PayloadValueType::String),
435            ("treasury_hash", PayloadValueType::String),
436            ("county_system", PayloadValueType::String),
437            ("county_version", PayloadValueType::Integer),
438            ("county_disposition", PayloadValueType::String),
439            ("county_hash", PayloadValueType::String),
440        ]);
441        registrar.register_record_schema(schema)?;
442        registrar.register_ingress(issue_descriptor())?;
443
444        let mut publish = BoundarySystemContract::new(
445            "publish-order",
446            BoundaryPhase::DomainDeltaProposal,
447            SystemCadence::EventDriven,
448        );
449        publish.reads = vec![order_state(), StateKey::core_ingress()];
450        publish.writes = vec![order_state()];
451        publish.plugin_ingress_targets = vec![
452            canwu_api::PluginIngressTarget {
453                target_plugin: TREASURY_PLUGIN.to_owned(),
454                packet_type: EXECUTE_INGRESS.to_owned(),
455            },
456            canwu_api::PluginIngressTarget {
457                target_plugin: COUNTY_PLUGIN.to_owned(),
458                packet_type: EXECUTE_INGRESS.to_owned(),
459            },
460        ];
461        publish.visibility = StateVisibility::SameBoundary;
462        registrar.register_boundary_system(publish, publish_order)?;
463
464        let mut audit = BoundarySystemContract::new(
465            "audit-order",
466            BoundaryPhase::StrategicAggregation,
467            SystemCadence::EventDriven,
468        );
469        audit.reads = vec![
470            order_state(),
471            treasury_state(),
472            county_state(),
473            StateKey::core_ingress(),
474        ];
475        registrar.register_boundary_system(audit, audit_order)
476    }
477}
478
479struct TreasuryPlugin;
480
481impl SimulationPlugin for TreasuryPlugin {
482    fn name(&self) -> &'static str {
483        TREASURY_PLUGIN
484    }
485
486    fn version(&self) -> &'static str {
487        "1"
488    }
489
490    fn semantic_hash(&self) -> &'static str {
491        "0000000000000000000000000000000000000000000000000000000000000302"
492    }
493
494    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
495        let mut schema = DomainRecordSchema::for_entity::<TreasuryActionRecord>();
496        schema.payload_schema = object_schema(&[
497            ("status", PayloadValueType::String),
498            ("grain_units", PayloadValueType::Integer),
499        ]);
500        registrar.register_record_schema(schema)?;
501        registrar.register_ingress(execute_descriptor())?;
502        let mut prepare = BoundarySystemContract::new(
503            "prepare-treasury",
504            BoundaryPhase::HistoricalCandidateEvaluation,
505            SystemCadence::EventDriven,
506        );
507        prepare.reads = vec![order_state(), StateKey::core_ingress()];
508        prepare.writes = vec![treasury_state()];
509        prepare.visibility = StateVisibility::SameBoundary;
510        registrar.register_boundary_system(prepare, prepare_treasury)
511    }
512}
513
514struct CountyPlugin;
515
516impl SimulationPlugin for CountyPlugin {
517    fn name(&self) -> &'static str {
518        COUNTY_PLUGIN
519    }
520
521    fn version(&self) -> &'static str {
522        "1"
523    }
524
525    fn semantic_hash(&self) -> &'static str {
526        "0000000000000000000000000000000000000000000000000000000000000303"
527    }
528
529    fn register(&self, registrar: &mut PluginRegistrar<'_>) -> Result<(), CanwuError> {
530        let mut schema = DomainRecordSchema::for_entity::<CountyActionRecord>();
531        schema.payload_schema = object_schema(&[
532            ("status", PayloadValueType::String),
533            ("grain_units", PayloadValueType::Integer),
534        ]);
535        registrar.register_record_schema(schema)?;
536        registrar.register_ingress(execute_descriptor())?;
537        let mut prepare = BoundarySystemContract::new(
538            "prepare-county",
539            BoundaryPhase::HistoricalCandidateEvaluation,
540            SystemCadence::EventDriven,
541        );
542        prepare.reads = vec![order_state(), StateKey::core_ingress()];
543        prepare.writes = vec![county_state()];
544        prepare.visibility = StateVisibility::SameBoundary;
545        registrar.register_boundary_system(prepare, prepare_county)
546    }
pub fn register_internal_ingress( &mut self, descriptor: PluginIngressDescriptor, ) -> Result<PluginIngressPermit, CanwuError>

Registers an ingress that cannot be authored through the ordinary host API and returns the opaque capability required to enqueue it.

pub fn register_internal_ingress_with_archive_retention( &mut self, descriptor: PluginIngressDescriptor, namespace: impl Into<String>, object_id_json_pointers: Vec<String>, ) -> Result<PluginIngressPermit, CanwuError>

Registers an internal ingress whose single retained archive root must equal every declared JSON-pointer field in its payload.