pub struct SchemaRegistry { /* private fields */ }Implementations
Sourceimpl SchemaRegistry
impl SchemaRegistry
Sourcepub fn register(
&mut self,
schema: TypeSchema,
) -> Result<(), SchemaRegistryError>
pub fn register( &mut self, schema: TypeSchema, ) -> Result<(), SchemaRegistryError>
Registers a schema without replacing a different existing definition.
Re-registering an identical definition is accepted for idempotent plugin registration.
Errors
Returns SchemaRegistryError::DuplicateType when the type name is
already registered with a different definition.
pub fn get(&self, type_name: &str) -> Option<&TypeSchema>
pub fn iter(&self) -> impl Iterator<Item = &TypeSchema>