SimDuration

Struct SimDuration 

pub struct SimDuration(/* private fields */);

Implementations

Source

impl SimDuration

pub const ZERO: SimDuration

pub const fn minutes(minutes: i64) -> SimDuration

Examples found in repository?
examples/continuous_game_loop.rs (line 17)
17const SIMULATION_QUANTUM: SimDuration = SimDuration::minutes(1);
pub const fn hours(hours: i64) -> SimDuration

Creates a duration from hours.

Panics

Panics when the value cannot be represented in simulation minutes. Use Self::checked_hours for data-dependent input.

pub const fn checked_hours(hours: i64) -> Option<SimDuration>

pub const fn days(days: i64) -> SimDuration

Creates a duration from days.

Panics

Panics when the value cannot be represented in simulation minutes. Use Self::checked_days for data-dependent input.

Examples found in repository?
examples/uncertainty_resolution.rs (line 163)
148fn random_branch() -> Result<(), Box<dyn std::error::Error>> {
149    let mut canwu = Canwu::demo(202)?;
150    canwu.register_plugin(&UncertaintyPlugin)?;
151    enqueue_ticket(
152        &mut canwu,
153        RANDOM_TICKET,
154        1,
155        DecisionControllerBinding::new(
156            "law-random-controller",
157            DecisionPolicyIdentity::new(DecisionPolicyKind::Random, "weighted-random", "1"),
158            DecisionAuthority::Actor {
159                actor: Canwu::demo_ids().commander,
160            },
161        ),
162    )?;
163    let selection_at = SimTime::EPOCH + SimDuration::days(1);
164    canwu.schedule_calendar_boundary(selection_at, vec![SystemCadence::Daily])?;
165    canwu.step_canonical()?.expect("random source boundary");
166    canwu
167        .step_canonical()?
168        .expect("generated decision resolution boundary");
169    let trace = canwu
170        .decision_trace(canwu_api::DecisionTraceId::new(1))
171        .expect("random decision trace");
172    println!("random_trace={}", serde_json::to_string(trace)?);
173    Ok(())
174}
More examples
Hide additional examples
examples/decision_ticket.rs (line 78)
29fn open_aid_request(canwu: &mut Canwu, ids: DemoIds) -> Result<(), Box<dyn std::error::Error>> {
30    let now = canwu.time();
31    let controller = DecisionControllerBinding::new(
32        "warlord-b-ai",
33        DecisionPolicyIdentity::new(DecisionPolicyKind::Utility, "aid-utility", "1"),
34        DecisionAuthority::Actor {
35            actor: ids.commander,
36        },
37    )
38    .with_command_subject(EntityRef::Army(ids.army));
39
40    canwu.enqueue_decision(
41        now,
42        0,
43        DecisionIngressRequest::new(
44            DecisionRequestId::new(1),
45            canwu.revision(),
46            DecisionMutation::RegisterController { controller },
47        ),
48    )?;
49    canwu.enqueue_decision(
50        now,
51        0,
52        DecisionIngressRequest::new(
53            DecisionRequestId::new(2),
54            canwu.revision(),
55            DecisionMutation::Open {
56                ticket: DecisionTicketDraft {
57                    id: DecisionTicketId::new(1),
58                    definition: "beiyang.request-military-aid".to_owned(),
59                    decision_maker: EntityRef::Person(ids.commander),
60                    assigned_controller: "warlord-b-ai".to_owned(),
61                    summary: "Neighboring warlord requests immediate military aid".to_owned(),
62                    context: DecisionContext::new(
63                        "beiyang.aid-request.v1",
64                        json!({
65                            "requester": "warlord-a",
66                            "battle": "ongoing-front",
67                            "common_enemy": true
68                        }),
69                    ),
70                    options: vec![DecisionOption {
71                        action: DecisionAction::None,
72                        utility_inputs: BTreeMap::from([
73                            ("home_defense".to_owned(), 80),
74                            ("alliance".to_owned(), -40),
75                        ]),
76                        ..DecisionOption::new("decline", "Decline aid")
77                    }],
78                    deadline: Some(now + SimDuration::days(2)),
79                    parent_ticket: None,
80                },
81            },
82        ),
83    )?;
84    canwu.step_canonical()?.expect("decision intake boundary");
85    Ok(())
86}
pub const fn checked_days(days: i64) -> Option<SimDuration>

pub const fn as_minutes(self) -> i64

Examples found in repository?
examples/continuous_game_loop.rs (line 435)
434fn std_duration(duration: SimDuration) -> Duration {
435    let minutes = u64::try_from(duration.as_minutes())
436        .expect("presentation interpolation requires a non-negative duration");
437    Duration::from_secs(
438        minutes
439            .checked_mul(60)
440            .expect("presentation duration must remain representable"),
441    )
442}
pub const fn is_negative(self) -> bool

pub const fn checked_add(self, other: SimDuration) -> Option<SimDuration>