SimDuration

Struct SimDuration 

pub struct SimDuration(/* private fields */);

Implementations

Source

impl SimDuration

pub const ZERO: SimDuration

pub const fn minutes(minutes: i64) -> SimDuration

Examples found in repository?
examples/continuous_game_loop.rs (line 17)
17const SIMULATION_QUANTUM: SimDuration = SimDuration::minutes(1);
pub const fn hours(hours: i64) -> SimDuration

Creates a duration from hours.

Panics

Panics when the value cannot be represented in simulation minutes. Use Self::checked_hours for data-dependent input.

pub const fn checked_hours(hours: i64) -> Option<SimDuration>

pub const fn days(days: i64) -> SimDuration

Creates a duration from days.

Panics

Panics when the value cannot be represented in simulation minutes. Use Self::checked_days for data-dependent input.

Examples found in repository?
examples/move_army.rs (line 15)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let mut canwu = Canwu::demo(35)?;
5    let ids = Canwu::demo_ids();
6
7    canwu.act(
8        ids.commander,
9        SemanticAction::MoveEntity {
10            subject: EntityRef::Army(ids.army),
11            destination: ids.eastern_territory,
12            cargo: Vec::new(),
13        },
14    )?;
15    let arrival_events = canwu.advance(SimDuration::days(1))?;
16
17    let commander = canwu.observe(ids.commander, &ObserveRequest::default())?;
18    let observer = canwu.observe(ids.observer, &ObserveRequest::default())?;
19    println!("time: {}", canwu.time());
20    println!("arrival events: {}", arrival_events.len());
21    println!(
22        "commander knows location: {:?}",
23        commander.known_armies[0].known_location
24    );
25    println!(
26        "observer still believes location: {:?}",
27        observer.known_armies[0].known_location
28    );
29
30    canwu.advance(SimDuration::days(3))?;
31    let observer = canwu.observe(ids.observer, &ObserveRequest::default())?;
32    println!(
33        "observer after report: {:?}",
34        observer.known_armies[0].known_location
35    );
36    Ok(())
37}
More examples
Hide additional examples
examples/decision_ticket.rs (line 90)
41fn open_aid_request(canwu: &mut Canwu, ids: DemoIds) -> Result<(), Box<dyn std::error::Error>> {
42    let now = canwu.time();
43    let controller = DecisionControllerBinding::new(
44        "warlord-b-ai",
45        DecisionPolicyIdentity::new(DecisionPolicyKind::Utility, "aid-utility", "1"),
46        DecisionAuthority::Actor {
47            actor: ids.commander,
48        },
49    )
50    .with_command_subject(EntityRef::Army(ids.army));
51
52    canwu.enqueue_decision(
53        now,
54        0,
55        DecisionIngressRequest::new(
56            DecisionRequestId::new(1),
57            canwu.revision(),
58            DecisionMutation::RegisterController { controller },
59        ),
60    )?;
61    canwu.enqueue_decision(
62        now,
63        0,
64        DecisionIngressRequest::new(
65            DecisionRequestId::new(2),
66            canwu.revision(),
67            DecisionMutation::Open {
68                ticket: DecisionTicketDraft {
69                    id: DecisionTicketId::new(1),
70                    definition: "beiyang.request-military-aid".to_owned(),
71                    decision_maker: EntityRef::Person(ids.commander),
72                    assigned_controller: "warlord-b-ai".to_owned(),
73                    summary: "Neighboring warlord requests immediate military aid".to_owned(),
74                    context: DecisionContext::new(
75                        "beiyang.aid-request.v1",
76                        json!({
77                            "requester": "warlord-a",
78                            "battle": "ongoing-front",
79                            "common_enemy": true
80                        }),
81                    ),
82                    options: vec![DecisionOption {
83                        action: DecisionAction::None,
84                        utility_inputs: BTreeMap::from([
85                            ("home_defense".to_owned(), 80),
86                            ("alliance".to_owned(), -40),
87                        ]),
88                        ..DecisionOption::new("decline", "Decline aid")
89                    }],
90                    deadline: Some(now + SimDuration::days(2)),
91                },
92            },
93        ),
94    )?;
95    canwu.step_canonical()?.expect("decision intake boundary");
96    Ok(())
97}
pub const fn checked_days(days: i64) -> Option<SimDuration>

pub const fn as_minutes(self) -> i64

Examples found in repository?
examples/continuous_game_loop.rs (line 435)
434fn std_duration(duration: SimDuration) -> Duration {
435    let minutes = u64::try_from(duration.as_minutes())
436        .expect("presentation interpolation requires a non-negative duration");
437    Duration::from_secs(
438        minutes
439            .checked_mul(60)
440            .expect("presentation duration must remain representable"),
441    )
442}
pub const fn is_negative(self) -> bool

pub const fn checked_add(self, other: SimDuration) -> Option<SimDuration>