SimDuration

Struct SimDuration 

pub struct SimDuration(/* private fields */);

Implementations

Source

impl SimDuration

pub const ZERO: SimDuration

pub const fn minutes(minutes: i64) -> SimDuration

Examples found in repository?
examples/continuous_game_loop.rs (line 17)
17const SIMULATION_QUANTUM: SimDuration = SimDuration::minutes(1);
pub const fn hours(hours: i64) -> SimDuration

Creates a duration from hours.

Panics

Panics when the value cannot be represented in simulation minutes. Use Self::checked_hours for data-dependent input.

pub const fn checked_hours(hours: i64) -> Option<SimDuration>

pub const fn days(days: i64) -> SimDuration

Creates a duration from days.

Panics

Panics when the value cannot be represented in simulation minutes. Use Self::checked_days for data-dependent input.

Examples found in repository?
examples/move_army.rs (line 14)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let mut canwu = Canwu::demo(35)?;
5    let ids = Canwu::demo_ids();
6
7    canwu.act(
8        ids.commander,
9        SemanticAction::MoveArmy {
10            army: ids.army,
11            destination: ids.eastern_territory,
12        },
13    )?;
14    let arrival_events = canwu.advance(SimDuration::days(1))?;
15
16    let commander = canwu.observe(ids.commander, &ObserveRequest::default())?;
17    let observer = canwu.observe(ids.observer, &ObserveRequest::default())?;
18    println!("time: {}", canwu.time());
19    println!("arrival events: {}", arrival_events.len());
20    println!(
21        "commander knows location: {:?}",
22        commander.known_armies[0].known_location
23    );
24    println!(
25        "observer still believes location: {:?}",
26        observer.known_armies[0].known_location
27    );
28
29    canwu.advance(SimDuration::days(3))?;
30    let observer = canwu.observe(ids.observer, &ObserveRequest::default())?;
31    println!(
32        "observer after report: {:?}",
33        observer.known_armies[0].known_location
34    );
35    Ok(())
36}
pub const fn checked_days(days: i64) -> Option<SimDuration>

pub const fn as_minutes(self) -> i64

Examples found in repository?
examples/continuous_game_loop.rs (line 434)
433fn std_duration(duration: SimDuration) -> Duration {
434    let minutes = u64::try_from(duration.as_minutes())
435        .expect("presentation interpolation requires a non-negative duration");
436    Duration::from_secs(
437        minutes
438            .checked_mul(60)
439            .expect("presentation duration must remain representable"),
440    )
441}
pub const fn is_negative(self) -> bool

pub const fn checked_add(self, other: SimDuration) -> Option<SimDuration>